@@ -311,12 +311,14 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
         ui_defaults_conf = trackmeconf.get("trackme_ui_defaults", {})
         ui_default_theme = ui_defaults_conf.get("default_theme", "dark")
         ui_auto_refresh = ui_defaults_conf.get("auto_refresh", "1")
+        ui_auto_refresh_interval_seconds = ui_defaults_conf.get("auto_refresh_interval_seconds", "5")
         ui_vtenants_card_detail_level = ui_defaults_conf.get("vtenants_card_detail_level", "0")
 
         # Add ui_default_theme to response (system-level setting)
         user_prefs_dict = {
             "ui_default_theme": ui_default_theme,
             "ui_auto_refresh": ui_auto_refresh,
+            "ui_auto_refresh_interval_seconds": ui_auto_refresh_interval_seconds,
             "ui_vtenants_card_detail_level": ui_vtenants_card_detail_level,
         }
 
