@@ -299,6 +299,15 @@ fields_trackme_ui_defaults = [
             regex=r"""^(1|0)$""", 
         )
     ), 
+    field.RestField(
+        'auto_refresh_interval_seconds',
+        required=True,
+        encrypted=False,
+        default='5',
+        validator=validator.Pattern(
+            regex=r"""^([5-9]|[1-9]\d|[12]\d{2}|300)$""", 
+        )
+    ), 
     field.RestField(
         'vtenants_card_detail_level',
         required=True,
