@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -1051,6 +1051,7 @@ class TrackMeStateful(GeneratingCommand):
         object_state_cache = {}  # object_id -> (object_state, anomaly_reason, status_message_json, monitored_state)
         stateful_record_cache = {}  # object_id -> stateful_record
         validation_cache = {}  # (object_id, alerting_states_tuple) -> ((is_valid, actual_object_state, error_message), timestamp)
+        score_cache = {}  # object_id -> (score, score_definition)
         
         log.info(
             f"activity=initialization, tenant_id={self.tenant_id}, decision=caches_initialized, "
@@ -1233,6 +1234,140 @@ class TrackMeStateful(GeneratingCommand):
             
             for dedup_key, (yield_event, event_time, context, prefilter_reason) in events_by_key.items():
                 object_id, sourcetype = dedup_key
+                
+                # Load score and score_definition from component data via REST call
+                tenant_id = context.get('tenant_id')
+                component = context.get('component')
+                
+                # Check cache first to avoid redundant REST calls
+                score = None
+                score_definition = None
+                if object_id in score_cache:
+                    score, score_definition = score_cache[object_id]
+                    log.debug(
+                        f"activity=load_score, tenant_id={tenant_id}, object_id={object_id}, "
+                        f"decision=cache_hit, score={score}"
+                    )
+                elif tenant_id and component and object_id:
+                    try:
+                        # Build the REST endpoint URL
+                        url = f"{server_uri}/services/trackme/v2/component/load_component_data"
+                        
+                        # Prepare query parameters
+                        params = {
+                            "tenant_id": tenant_id,
+                            "component": component,
+                            "pagination_mode": "local",
+                            "filter_key": object_id,
+                        }
+                        
+                        log.debug(
+                            f"activity=load_score, tenant_id={tenant_id}, component={component}, object_id={object_id}, "
+                            f"url={url}, params={params}"
+                        )
+                        
+                        # Make the REST call
+                        response = requests.get(
+                            url,
+                            headers=header,
+                            verify=False,
+                            params=params,
+                            timeout=30,
+                        )
+                        
+                        # Check response status
+                        if response.status_code == 200:
+                            try:
+                                response_json = response.json()
+                                
+                                # Handle different response structures:
+                                # - If pagination_mode="local": response is {"payload": [records...], "status": 200}
+                                #   Splunk REST framework may unwrap to just [records...]
+                                # - If pagination_mode="remote": response is {"payload": {"data": [records...], "last_page": ...}, "status": 200}
+                                
+                                # Check if response is wrapped in "payload"
+                                if isinstance(response_json, dict) and "payload" in response_json:
+                                    payload = response_json["payload"]
+                                    # Check if payload has "data" key (remote pagination) or is a list (local pagination)
+                                    if isinstance(payload, dict) and "data" in payload:
+                                        data = payload["data"]
+                                    elif isinstance(payload, list):
+                                        data = payload
+                                    else:
+                                        data = []
+                                # Check if response is a list directly (local pagination, unwrapped)
+                                elif isinstance(response_json, list):
+                                    data = response_json
+                                # Check if response has "data" key directly
+                                elif isinstance(response_json, dict) and "data" in response_json:
+                                    data = response_json["data"]
+                                else:
+                                    data = []
+                                
+                                if data and len(data) > 0:
+                                    # Get the first record (should be only one when filtering by object_id)
+                                    record = data[0]
+                                    
+                                    # Extract score and score_definition
+                                    score_raw = record.get("score")
+                                    score_definition = record.get("score_definition")
+                                    
+                                    # Convert score to integer (score is always an integer)
+                                    score = None
+                                    if score_raw is not None:
+                                        try:
+                                            score = int(float(score_raw))  # Convert to float first to handle string "100.0", then to int
+                                        except (ValueError, TypeError):
+                                            log.warning(
+                                                f"activity=load_score, tenant_id={tenant_id}, object_id={object_id}, "
+                                                f"decision=error, reason=failed_to_convert_score_to_int, score_raw={score_raw}"
+                                            )
+                                            score = None
+                                    
+                                    # Cache the results
+                                    score_cache[object_id] = (score, score_definition)
+                                    
+                                    log.debug(
+                                        f"activity=load_score, tenant_id={tenant_id}, object_id={object_id}, "
+                                        f"score={score}, decision=cached"
+                                    )
+                                else:
+                                    # Cache None values when data is empty to avoid redundant REST calls
+                                    # This handles the case where REST call succeeds but no records found for object_id
+                                    score_cache[object_id] = (None, None)
+                                    log.debug(
+                                        f"activity=load_score, tenant_id={tenant_id}, object_id={object_id}, "
+                                        f"decision=cached_empty, reason=no_data_returned_from_rest_call"
+                                    )
+                            except (json.JSONDecodeError, KeyError, IndexError, TypeError) as e:
+                                log.warning(
+                                    f"activity=load_score, tenant_id={tenant_id}, component={component}, object_id={object_id}, "
+                                    f"decision=error, reason=failed_to_parse_response, exception={str(e)}"
+                                )
+                                # Cache None values to avoid repeated failed calls
+                                score_cache[object_id] = (None, None)
+                        else:
+                            log.warning(
+                                f"activity=load_score, tenant_id={tenant_id}, component={component}, object_id={object_id}, "
+                                f"decision=error, reason=rest_call_failed, status_code={response.status_code}, "
+                                f"response_text={response.text[:200]}"
+                            )
+                            # Cache None values to avoid repeated failed calls
+                            score_cache[object_id] = (None, None)
+                    except Exception as e:
+                        log.warning(
+                            f"activity=load_score, tenant_id={tenant_id}, component={component}, object_id={object_id}, "
+                            f"decision=error, reason=exception_during_rest_call, exception={str(e)}"
+                        )
+                        # Cache None values to avoid repeated failed calls
+                        score_cache[object_id] = (None, None)
+                
+                # Add to yield_event if present
+                if score is not None:
+                    yield_event["score"] = score
+                if score_definition is not None:
+                    yield_event["score_definition"] = score_definition
+                
                 events_yielded_records.append(yield_event)
                 
                 log.debug(
@@ -1259,7 +1394,8 @@ class TrackMeStateful(GeneratingCommand):
                 f"reason=trackmestateful_command_completed, run_time_seconds={round(time.time() - start, 3)}, "
                 f"events_processed={events_processed}, events_yielded={events_yielded}, events_filtered={events_filtered}, "
                 f"cache_stats=object_id_cache_size={len(object_id_cache)}, object_state_cache_size={len(object_state_cache)}, "
-                f"stateful_record_cache_size={len(stateful_record_cache)}, validation_cache_size={len(validation_cache)}"
+                f"stateful_record_cache_size={len(stateful_record_cache)}, validation_cache_size={len(validation_cache)}, "
+                f"score_cache_size={len(score_cache)}"
             )
 
         except Exception as e:
